@@ -332,7 +332,10 @@ def train_new_model(dataframe, input_dim, hidden_dim, model_path, learning_rate=
 
     model = Binary_Network(input_dim, hidden_dim).to(device)
     criterion = nn.BCELoss()
-    optimiser = optim.Adam(model.parameters(), learning_rate, weight_decay)
+    if weight_decay > 0.0:
+        optimiser = optim.Adam(model.parameters(), learning_rate, weight_decay)
+    else:
+        optimiser = optim.Adam(model.parameters(), learning_rate)
     running_loss = run_model(model, trainloader, num_epochs, criterion, optimiser)
     evaluate_model(model, valloader, val_labels, False)
     plt.plot(running_loss)
